@@ -32,8 +32,8 @@ const int border_width = 32;
 #define PIECE_START 16  //棋子开始数字 start number of chessman
 #define PIECE_END   48  //棋子结束数字 end number of chessman
 #define PLACE_ALL PLACE_LEFT | PLACE_RIGHT
-#define IMGAGE_DIR DATA_DIR"/wood/"
-#define IMGAGE_SMALL_DIR DATA_DIR"/wood-small/"
+#define IMGAGE_DIR DATA_DIR"/themes/west/"
+#define IMGAGE_SMALL_DIR DATA_DIR"/themes/west-small/"
 #define HEX_ESCAPE '%'
 
 
@@ -126,6 +126,7 @@ Board::Board(MainWindow& win) :
 	,m_search_depth(8)
 	,m_usebook(true)
 	,m_human_black(false)
+	,theme("wood")
 {
 
 	std::list<Gtk::TargetEntry> listTargets;
@@ -134,7 +135,6 @@ Board::Board(MainWindow& win) :
 
 
 	this->set_size_request(221,277);
-	//this->set_size_request(521,577);
 
 	this->drag_dest_set(listTargets);
 	this->signal_drag_data_received().connect(
@@ -146,71 +146,88 @@ Board::Board(MainWindow& win) :
 	p_pgnfile=new Pgnfile(m_engine);
 	m_engine.init_snapshot(start_fen);
 	m_robot.set_out_slot(sigc::mem_fun(*this, &Board::robot_log));
-	//m_network.set_out_slot(sigc::mem_fun(*this, &Board::network_log));
 	this->set_events(Gdk::BUTTON_PRESS_MASK|Gdk::EXPOSURE_MASK);
 
 	this->show_all();
 
-
-
 }
 
+
 Board::~Board()
 {
 	if(timer.connected())
 		timer.disconnect();
 	m_robot.send_ctrl_command("quit\n");
 	m_robot.stop();
-	//m_network.stop();
+}
+
+void Board::set_themes(const std::string& themes_)
+{
+	theme = themes_;
+	/** 加载所需要图片进内存*/
+	load_images();
+	redraw();
+}
+Glib::RefPtr<Gdk::Pixbuf> Board::get_pic(const std::string& name_)
+{
+	char path[1024];
+	sprintf(path, DATA_DIR"/themes/%s/%s",theme.c_str(),name_.c_str());
+	return Gdk::Pixbuf::create_from_file(path);
+
+}
+
+Glib::RefPtr<Gdk::Pixbuf> Board::get_spic(const std::string& name_)
+{
+	char path[1024];
+	sprintf(path, DATA_DIR"/themes/%s-small/%s",theme.c_str(),name_.c_str());
+	return Gdk::Pixbuf::create_from_file(path);
+
 }
 
 void Board::load_images()
 {
-	bg_image = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"bg.png");
-
+	bg_image = get_pic("bg.png");
 	if(is_small_board){
-		chessman_images[BLACK_ADVISOR] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_advisor.png");
-		chessman_images[BLACK_BISHOP] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_bishop.png");
-		chessman_images[BLACK_CANNON] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_cannon.png");
-		chessman_images[BLACK_KING] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_king.png");
-		chessman_images[BLACK_KING_DIE] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_king_die.png");
-		chessman_images[BLACK_KNIGHT] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_knight.png");
-		chessman_images[BLACK_PAWN] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_pawn.png");
-		chessman_images[BLACK_ROOK] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"black_rook.png");
-		chessman_images[RED_ADVISOR] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_advisor.png");
-		chessman_images[RED_BISHOP] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_bishop.png");
-		chessman_images[RED_CANNON] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_cannon.png");
-		chessman_images[RED_KING] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_king.png");
-		chessman_images[RED_KING_DIE] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_king_die.png");
-		chessman_images[RED_KNIGHT] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_knight.png");
-		chessman_images[RED_PAWN] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_pawn.png");
-		chessman_images[RED_ROOK] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"red_rook.png");
-		chessman_images[SELECTED_CHESSMAN] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"select.png");
-		chessman_images[NULL_CHESSMAN] = Gdk::Pixbuf::create_from_file(IMGAGE_SMALL_DIR"null.png");
+		chessman_images[BLACK_ADVISOR] = get_spic("black_advisor.png");
+		chessman_images[BLACK_BISHOP] = get_spic("black_bishop.png");
+		chessman_images[BLACK_CANNON] = get_spic("black_cannon.png");
+		chessman_images[BLACK_KING] = get_spic("black_king.png");
+		chessman_images[BLACK_KING_DIE] = get_spic("black_king_die.png");
+		chessman_images[BLACK_KNIGHT] = get_spic("black_knight.png");
+		chessman_images[BLACK_PAWN] = get_spic("black_pawn.png");
+		chessman_images[BLACK_ROOK] = get_spic("black_rook.png");
+		chessman_images[RED_ADVISOR] = get_spic("red_advisor.png");
+		chessman_images[RED_BISHOP] = get_spic("red_bishop.png");
+		chessman_images[RED_CANNON] = get_spic("red_cannon.png");
+		chessman_images[RED_KING] = get_spic("red_king.png");
+		chessman_images[RED_KING_DIE] = get_spic("red_king_die.png");
+		chessman_images[RED_KNIGHT] = get_spic("red_knight.png");
+		chessman_images[RED_PAWN] = get_spic("red_pawn.png");
+		chessman_images[RED_ROOK] = get_spic("red_rook.png");
+		chessman_images[SELECTED_CHESSMAN] = get_spic("select.png");
+		chessman_images[NULL_CHESSMAN] = get_spic("null.png");
 	}
 	else{
 
-		chessman_images[BLACK_ADVISOR] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_advisor.png");
-		chessman_images[BLACK_BISHOP] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_bishop.png");
-		chessman_images[BLACK_CANNON] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_cannon.png");
-		chessman_images[BLACK_KING] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_king.png");
-		chessman_images[BLACK_KING_DIE] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_king_die.png");
-		chessman_images[BLACK_KNIGHT] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_knight.png");
-		chessman_images[BLACK_PAWN] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_pawn.png");
-		chessman_images[BLACK_ROOK] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"black_rook.png");
-		chessman_images[RED_ADVISOR] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_advisor.png");
-		chessman_images[RED_BISHOP] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_bishop.png");
-		chessman_images[RED_CANNON] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_cannon.png");
-		chessman_images[RED_KING] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_king.png");
-		chessman_images[RED_KING_DIE] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_king_die.png");
-		chessman_images[RED_KNIGHT] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_knight.png");
-		chessman_images[RED_PAWN] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_pawn.png");
-		chessman_images[RED_ROOK] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"red_rook.png");
-		chessman_images[SELECTED_CHESSMAN] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"select.png");
-		chessman_images[NULL_CHESSMAN] = Gdk::Pixbuf::create_from_file(IMGAGE_DIR"null.png");
-
+		chessman_images[BLACK_ADVISOR] = get_pic("black_advisor.png");
+		chessman_images[BLACK_BISHOP] = get_pic("black_bishop.png");
+		chessman_images[BLACK_CANNON] = get_pic("black_cannon.png");
+		chessman_images[BLACK_KING] = get_pic("black_king.png");
+		chessman_images[BLACK_KING_DIE] = get_pic("black_king_die.png");
+		chessman_images[BLACK_KNIGHT] = get_pic("black_knight.png");
+		chessman_images[BLACK_PAWN] = get_pic("black_pawn.png");
+		chessman_images[BLACK_ROOK] = get_pic("black_rook.png");
+		chessman_images[RED_ADVISOR] = get_pic("red_advisor.png");
+		chessman_images[RED_BISHOP] = get_pic("red_bishop.png");
+		chessman_images[RED_CANNON] = get_pic("red_cannon.png");
+		chessman_images[RED_KING] = get_pic("red_king.png");
+		chessman_images[RED_KING_DIE] = get_pic("red_king_die.png");
+		chessman_images[RED_KNIGHT] = get_pic("red_knight.png");
+		chessman_images[RED_PAWN] = get_pic("red_pawn.png");
+		chessman_images[RED_ROOK] = get_pic("red_rook.png");
+		chessman_images[SELECTED_CHESSMAN] = get_pic("select.png");
+		chessman_images[NULL_CHESSMAN] = get_pic("null.png");
 	}
-	
 }
 
 void Board::configure_board(int _width)
