@@ -39,6 +39,7 @@ class Board : public Gtk::DrawingArea
 		int init_send_socket();
 		void close_send_socket();
 		void send_to_socket(const std::string& cmd_);
+		void set_themes(const std::string& themes_);
 
 
 	protected:
@@ -47,6 +48,9 @@ class Board : public Gtk::DrawingArea
 		bool on_configure_event(GdkEventConfigure* ev);
 		bool on_button_press_event(GdkEventButton* ev);
 
+		Glib::RefPtr<Gdk::Pixbuf> get_pic(const std::string& name_);
+		Glib::RefPtr<Gdk::Pixbuf> get_spic(const std::string& name_);
+
 		/** 由棋盘9x10坐标得到棋盘真实坐标*/
 		/** get the true coordinate from 9x10 postion*/
 		Gdk::Point get_coordinate(int pos_x, int pos_y);
@@ -204,6 +208,8 @@ class Board : public Gtk::DrawingArea
 		std::string moves_lines;
 		/** 着法状态开头序列，potions fen xxx*/
 		const std::string postion_str;
+		/** 所使用的主题*/
+		std::string theme;
 
 		/** 背景图像 */
 		Glib::RefPtr<Gdk::Pixbuf> bg_image;
