@@ -28,7 +28,7 @@
 #include "gmchess.h"
 #include "Sound.h"
 
-#define version "0.29.2"
+#define version "0.29.3"
 
 Glib::ustring ui_info =
 "<ui>"
@@ -100,7 +100,7 @@ MainWindow::MainWindow():menubar(NULL)
 	btn_rue->signal_clicked().connect(
 			sigc::mem_fun(*this, &MainWindow::on_rue_game));
 
-	board= Gtk::manage(new Board(*this));
+	board = Gtk::manage(new Board(*this));
 	box_board->pack_start(*board);
 
 	this->add(*main_window);
@@ -110,7 +110,7 @@ MainWindow::MainWindow():menubar(NULL)
 	this->set_icon(ui_logo);
 	/** 设置菜单, set the menu*/
 	init_ui_manager();
-	 menubar = ui_manager->get_widget("/MenuBar");
+	menubar = ui_manager->get_widget("/MenuBar");
 	Gtk::VBox* menu_tool_box=0;
 	ui_xml->get_widget("box_menu_toolbar",menu_tool_box);
 	menu_tool_box->pack_start(*menubar,true,true);
@@ -167,6 +167,10 @@ MainWindow::MainWindow():menubar(NULL)
 	int _play_time= atoi(GMConf["play_time"].c_str());
 	if(_step_time>0&&_step_time<600 && _play_time>0)
 		board->set_time(_step_time,_play_time);
+	std::string theme_ = GMConf["themes"];
+	if(theme_.empty())
+		theme_ = "wood";
+	board->set_themes(theme_);
 }
 
 MainWindow::~MainWindow()
@@ -229,6 +233,7 @@ void MainWindow::init_conf()
 		GMConf["usebook"]="1";
 		GMConf["desktop_size"] = "1"; //0--small,1--big
 		GMConf["engine_depth"] ="5";
+		GMConf["themes"]="wood";
 		save_conf();
 
 		snprintf(file_dir,512,"%s/gmchess/files",homedir.c_str());
@@ -700,6 +705,7 @@ void MainWindow::on_conf_window_quit()
 		board->set_board_size(BIG_BOARD);
 	else
 		board->set_board_size(SMALL_BOARD);
+	board->set_themes(GMConf["themes"]);
 }
 void MainWindow::on_conf_window_close()
 {
@@ -733,7 +739,8 @@ void MainWindow::on_menu_about()
 		about->set_comments(_("GMChess is chinese chess game write by gtkmm"));
 		about->set_authors(authors);
 		about->set_license (_("This program is licenced under GNU General Public Licence (GPL) version 2."));
-		about->set_translator_credits("lerosua");
+		Glib::ustring transer = "zh_CN lerosua@gmail.com\nru Sadovnikov Dmitry <xbadcode@mail.ru>";
+		about->set_translator_credits(transer);
 
 
 	}
